Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(811)

Unified Diff: lib/src/codegen/js_codegen.dart

Issue 954773003: rename package:ddc to package:dev_compiler (Closed) Base URL: git@github.com:dart-lang/dev_compiler.git@master
Patch Set: Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « lib/src/codegen/html_codegen.dart ('k') | lib/src/codegen/reify_coercions.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: lib/src/codegen/js_codegen.dart
diff --git a/lib/src/codegen/js_codegen.dart b/lib/src/codegen/js_codegen.dart
index 717087369b0432bb1889d5c6bdad629898fc0260..bd74796a10f24f925584dc85cfa76fe2054ae7c9 100644
--- a/lib/src/codegen/js_codegen.dart
+++ b/lib/src/codegen/js_codegen.dart
@@ -14,10 +14,10 @@ import 'package:analyzer/src/generated/scanner.dart'
show StringToken, Token, TokenType;
import 'package:path/path.dart' as path;
-import 'package:ddc/src/checker/rules.dart';
-import 'package:ddc/src/info.dart';
-import 'package:ddc/src/report.dart';
-import 'package:ddc/src/utils.dart';
+import 'package:dev_compiler/src/checker/rules.dart';
+import 'package:dev_compiler/src/info.dart';
+import 'package:dev_compiler/src/report.dart';
+import 'package:dev_compiler/src/utils.dart';
import 'code_generator.dart';
// This must match the optional parameter name used in runtime.js
@@ -1979,6 +1979,6 @@ String jsLibraryName(LibraryElement library) => canonicalLibraryName(library);
/// Path to file that will be generated for [info].
// TODO(jmesserly): library directory should be relative to its package
// root. For example, "package:ddc/src/codegen/js_codegen.dart" would be:
// "ddc/src/codegen/js_codegen.js" under the output directory.
String jsOutputPath(LibraryInfo info) => '${info.name}/${info.name}.js';
« no previous file with comments | « lib/src/codegen/html_codegen.dart ('k') | lib/src/codegen/reify_coercions.dart » ('j') | no next file with comments »
@@ -1979,6 +1979,6 @@ String jsLibraryName(LibraryElement library) => canonicalLibraryName(library);
/// Path to file that will be generated for [info].
// TODO(jmesserly): library directory should be relative to its package
-// root. For example, "package:ddc/src/codegen/js_codegen.dart" would be:
+// root. For example, "package:dev_compiler/src/codegen/js_codegen.dart" would be:
// "ddc/src/codegen/js_codegen.js" under the output directory.
String jsOutputPath(LibraryInfo info) => '${info.name}/${info.name}.js';

Powered by Google App Engine
This is Rietveld 408576698